@@ -31,11 +31,9 @@ int snd_hwdep_close(snd_hwdep_t *hwdep);
 
 #include "hwdep_macros.h"
 
-#define snd_hwdep_info_alloca(ptr) do { *ptr = alloca(snd_hwdep_info_sizeof()); memset(*ptr, 0, snd_hwdep_info_sizeof()); } while (0)
-
-#define snd_hwdep_dsp_status_alloca(ptr) do { *ptr = alloca(snd_hwdep_dsp_status_sizeof()); memset(*ptr, 0, snd_hwdep_dsp_status_sizeof()); } while (0)
-
-#define snd_hwdep_dsp_image_alloca(ptr) do { *ptr = alloca(snd_hwdep_dsp_image_sizeof()); memset(*ptr, 0, snd_hwdep_dsp_image_sizeof()); } while (0)
+#define snd_hwdep_info_alloca(ptr)	__snd_alloca(ptr, snd_hwdep_info)
+#define snd_hwdep_dsp_status_alloca(ptr) __snd_alloca(ptr, snd_hwdep_dsp_status)
+#define snd_hwdep_dsp_image_alloca(ptr)	__snd_alloca(ptr, snd_hwdep_dsp_image)
 
 #endif /* __ALSA_HWDEP_H */
 
