@@ -44,7 +44,6 @@ struct _snd_pcm {
 	snd_pcm_uframes_t period_size;
 	unsigned int period_time;	/* period duration */
 	snd_interval_t periods;
-	unsigned int tick_time;
 	snd_pcm_uframes_t boundary;	/* pointers wrap point */
 	unsigned int info;		/* Info for returned setup */
 	unsigned int msbits;		/* used most significant bits */
@@ -1569,6 +1568,7 @@ int snd_pcm_hw_params_set_buffer_size_last(snd_pcm_t *pcm,
 
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_get_tick_time(const snd_pcm_hw_params_t *params,
 				    unsigned int *val, int *dir)
 {
@@ -1576,6 +1576,7 @@ int snd_pcm_hw_params_get_tick_time(const snd_pcm_hw_params_t *params,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_get_tick_time_min(const snd_pcm_hw_params_t *params,
 					unsigned int *val, int *dir)
 {
@@ -1583,6 +1584,7 @@ int snd_pcm_hw_params_get_tick_time_min(const snd_pcm_hw_params_t *params,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_get_tick_time_max(const snd_pcm_hw_params_t *params,
 					unsigned int *val, int *dir)
 {
@@ -1590,6 +1592,7 @@ int snd_pcm_hw_params_get_tick_time_max(const snd_pcm_hw_params_t *params,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_test_tick_time(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 				     unsigned int val, int dir)
 {
@@ -1598,6 +1601,7 @@ int snd_pcm_hw_params_test_tick_time(snd_pcm_t *pcm, snd_pcm_hw_params_t *params
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 				    unsigned int val, int dir)
 {
@@ -1606,6 +1610,7 @@ int snd_pcm_hw_params_set_tick_time(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time_min(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 					unsigned int *val, int *dir)
 {
@@ -1614,6 +1619,7 @@ int snd_pcm_hw_params_set_tick_time_min(snd_pcm_t *pcm, snd_pcm_hw_params_t *par
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time_max(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 					unsigned int *val, int *dir)
 {
@@ -1622,6 +1628,7 @@ int snd_pcm_hw_params_set_tick_time_max(snd_pcm_t *pcm, snd_pcm_hw_params_t *par
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time_minmax(snd_pcm_t *pcm,
 					   snd_pcm_hw_params_t *params,
 					   unsigned int *min, int *mindir,
@@ -1632,6 +1639,7 @@ int snd_pcm_hw_params_set_tick_time_minmax(snd_pcm_t *pcm,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time_near(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 					 unsigned int *val, int *dir)
 {
@@ -1640,6 +1648,7 @@ int snd_pcm_hw_params_set_tick_time_near(snd_pcm_t *pcm, snd_pcm_hw_params_t *pa
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time_first(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 					  unsigned int *val, int *dir)
 {
@@ -1648,6 +1657,7 @@ int snd_pcm_hw_params_set_tick_time_first(snd_pcm_t *pcm, snd_pcm_hw_params_t *p
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_hw_params_set_tick_time_last(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 					 unsigned int *val, int *dir)
 {
@@ -1690,6 +1700,7 @@ int snd_pcm_sw_params_get_tstamp_mode(const snd_pcm_sw_params_t *params,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_sw_params_set_sleep_min(snd_pcm_t *pcm, snd_pcm_sw_params_t *params,
 				    unsigned int val)
 {
@@ -1698,6 +1709,7 @@ int snd_pcm_sw_params_set_sleep_min(snd_pcm_t *pcm, snd_pcm_sw_params_t *params,
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_sw_params_get_sleep_min(const snd_pcm_sw_params_t *params,
 				    unsigned int *val)
 {
@@ -1723,6 +1735,7 @@ int snd_pcm_sw_params_get_avail_min(const snd_pcm_sw_params_t *params,
 
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_sw_params_set_xfer_align(snd_pcm_t *pcm, snd_pcm_sw_params_t *params,
 				     snd_pcm_uframes_t val)
 {
@@ -1731,6 +1744,7 @@ int snd_pcm_sw_params_set_xfer_align(snd_pcm_t *pcm, snd_pcm_sw_params_t *params
 }
 
 static inline
+__attribute__ ((deprecated))
 int snd_pcm_sw_params_get_xfer_align(const snd_pcm_sw_params_t *params,
 				     snd_pcm_uframes_t *val)
 {
@@ -1962,6 +1976,30 @@ void snd_pcm_info_set_stream(snd_pcm_info_t *obj, snd_pcm_stream_t val)
 	obj->stream = val;
 }
 
+static inline
+int snd_hw_htimestamp(snd_pcm_t *pcm, snd_pcm_uframes_t *avail,
+		      snd_htimestamp_t *tstamp)
+{
+	*avail = snd_pcm_avail_update(pcm);
+	*tstamp = pcm->mmap_status->tstamp;
+	return 0;
+}
+
+
+/*
+ * helper functions
+ */
+static inline
+int snd_pcm_get_params(snd_pcm_t *pcm,
+                       snd_pcm_uframes_t *buffer_size,
+                       snd_pcm_uframes_t *period_size)
+{
+	if (!pcm->setup)
+		return -EBADFD;
+	*buffer_size = pcm->buffer_size;
+	*period_size = pcm->period_size;
+	return 0;
+}
 
 /*
  * not implemented yet
@@ -2003,6 +2041,18 @@ snd_pcm_sframes_t snd_pcm_mmap_readn(snd_pcm_t *pcm, void **bufs,
 	return -ENXIO;
 }
 
+static inline __SALSA_NOT_IMPLEMENTED
+int snd_pcm_set_params(snd_pcm_t *pcm,
+                       snd_pcm_format_t format,
+                       snd_pcm_access_t access,
+                       unsigned int channels,
+                       unsigned int rate,
+                       int soft_resample,
+                       unsigned int latency)
+{
+	return -ENXIO;
+}
+
 #if SALSA_HAS_ASYNC_SUPPORT
 
 static inline
